# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .number_definition_params_field_configuration import NumberDefinitionParamsFieldConfiguration


class NumberDefinitionParams(UncheckedBaseModel):
    field_configuration: NumberDefinitionParamsFieldConfiguration
    name: str = pydantic.Field()
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .bad_request_errors_item import BadRequestErrorsItem


class BadRequest(UncheckedBaseModel):
    errors: typing.List[BadRequestErrorsItem]

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
